@@ -21,6 +21,7 @@ class Runner(Authenticate):
             'https_proxy': http_proxy
         }
         self.session.verify = os.getenv('verify') or self.asset.get('verify', True)
+        self.raise_for_status = os.getenv('raise_for_status') or self.asset.get('raise_for_status', True)
 
         super(Runner, self).__init__(self.session, self.asset, self.asset_manifest)
 
@@ -70,6 +71,8 @@ class Runner(Authenticate):
         }
 
     def parse_response(self, response):
+        if self.raise_for_status:
+            response.raise_for_status()
         try:
             json_body = response.json()
         except:
